==> eiffelstudio-18.11.10.2592.tar: F_code/C10/fo466.c <==
/*
 * Code for class FORMAL_DEC_AS
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "fo466.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {FORMAL_DEC_AS}.initialize */
void F1125_11718 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2, EIF_REFERENCE arg3, EIF_REFERENCE arg4, EIF_REFERENCE arg5, EIF_REFERENCE arg6)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	RTLD;
	
	RTLI(8);
	RTLR(0,arg2);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,arg3);
	RTLR(4,arg1);
	RTLR(5,arg4);
	RTLR(6,arg5);
	RTLR(7,arg6);
	RTLIU(8);
	
	RTGC;
	if ((EIF_BOOLEAN)(arg2 == NULL)) {
		tr1 = RTLNSMART(eif_new_type(1201, 1).id);
		F1197_12501(RTCW(tr1), ((EIF_INTEGER_32) 0L));
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) tr1;
	} else {
		RTAR(Current, arg2);
		*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) arg2;
	}
	RTAR(Current, arg3);
	*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) arg3;
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) arg1;
	if ((EIF_BOOLEAN)(arg4 != NULL)) {
		ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg4) + O9545[Dtype(arg4)-1186]);
		*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_1_0_0_) = (EIF_INTEGER_32) ti4_1;
	}
	if ((EIF_BOOLEAN)(arg5 != NULL)) {
		ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg5) + O9545[Dtype(arg5)-1186]);
		*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_1_0_1_) = (EIF_INTEGER_32) ti4_1;
	}
	if ((EIF_BOOLEAN)(arg6 != NULL)) {
		ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg6) + O9545[Dtype(arg6)-1186]);
		*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_1_0_2_) = (EIF_INTEGER_32) ti4_1;
	}
	RTLE;
}

/* {FORMAL_DEC_AS}.process */
void F1125_11719 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	
	
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R2480[Dtype(arg1)-202])(RTCW(arg1), Current);
}

/* {FORMAL_DEC_AS}.formal */
EIF_REFERENCE F1125_11720 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current);
}


/* {FORMAL_DEC_AS}.constrain_symbol */
EIF_REFERENCE F1125_11724 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_INTEGER_32 ti4_1;
	
	
	ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_1_0_0_);
	return (EIF_REFERENCE) F1113_11547(Current, arg1, ti4_1);
}

/* {FORMAL_DEC_AS}.create_keyword */
EIF_REFERENCE F1125_11725 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_INTEGER_32 ti4_1;
	
	
	ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_1_0_1_);
	return (EIF_REFERENCE) F1113_11546(Current, arg1, ti4_1);
}

/* {FORMAL_DEC_AS}.end_keyword */
EIF_REFERENCE F1125_11726 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_INTEGER_32 ti4_1;
	
	
	ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_1_0_2_);
	return (EIF_REFERENCE) F1113_11546(Current, arg1, ti4_1);
}

/* {FORMAL_DEC_AS}.constraints */
EIF_REFERENCE F1125_11734 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_1_);
}


/* {FORMAL_DEC_AS}.creation_feature_list */
EIF_REFERENCE F1125_11735 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_2_);
}


/* {FORMAL_DEC_AS}.first_token */
EIF_REFERENCE F1125_11736 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLR(3,Result);
	RTLIU(4);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current);
	Result = F1183_12308(RTCW(tr1), arg1);
	RTLE;
	return Result;
}

/* {FORMAL_DEC_AS}.last_token */
EIF_REFERENCE F1125_11737 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,arg1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,Result);
	RTLIU(4);
	
	RTGC;
	if ((EIF_BOOLEAN) ((EIF_BOOLEAN)(arg1 != NULL) && (EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_1_0_2_) != ((EIF_INTEGER_32) 0L)))) {
		RTLE;
		return (EIF_REFERENCE) F1125_11726(Current, arg1);
	} else {
		if ((EIF_BOOLEAN)(*(EIF_REFERENCE *)(Current + _REFACS_1_) != NULL)) {
			tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
			Result = F1197_12510(RTCW(tr1), arg1);
		} else {
			tr1 = *(EIF_REFERENCE *)(Current);
			Result = F1183_12309(RTCW(tr1), arg1);
		}
	}
	RTLE;
	return Result;
}

/* {FORMAL_DEC_AS}.is_equivalent */
EIF_BOOLEAN F1125_11748 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTGC;
	Result = '\0';
	tb1 = '\0';
	tr1 = *(EIF_REFERENCE *)(RTCW(arg1));
	if (F1113_11528(Current, *(EIF_REFERENCE *)(Current), tr1)) {
		tr1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_1_);
		tb1 = F1113_11528(Current, *(EIF_REFERENCE *)(Current + _REFACS_1_), tr1);
	}
	if (tb1) {
		tr1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_2_);
		Result = F1113_11528(Current, *(EIF_REFERENCE *)(Current + _REFACS_2_), tr1);
	}
	RTLE;
	return Result;
}

void EIF_Minit466 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C10/fo466.c <==
/*
 * Code for class FORMAL_DEC_AS
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "fo466.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {FORMAL_DEC_AS}.initialize */
void F1129_11741 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2, EIF_REFERENCE arg3, EIF_REFERENCE arg4, EIF_REFERENCE arg5, EIF_REFERENCE arg6)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	RTLD;
	
	RTLI(8);
	RTLR(0,arg2);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,arg3);
	RTLR(4,arg1);
	RTLR(5,arg4);
	RTLR(6,arg5);
	RTLR(7,arg6);
	RTLIU(8);
	
	RTGC;
	if ((EIF_BOOLEAN)(arg2 == NULL)) {
		tr1 = RTLNSMART(eif_new_type(1194, 1).id);
		F1192_12387(RTCW(tr1), ((EIF_INTEGER_32) 0L));
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) tr1;
	} else {
		RTAR(Current, arg2);
		*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) arg2;
	}
	RTAR(Current, arg3);
	*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) arg3;
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) arg1;
	if ((EIF_BOOLEAN)(arg4 != NULL)) {
		ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg4) + O9679[Dtype(arg4)-1201]);
		*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_1_0_0_) = (EIF_INTEGER_32) ti4_1;
	}
	if ((EIF_BOOLEAN)(arg5 != NULL)) {
		ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg5) + O9679[Dtype(arg5)-1201]);
		*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_1_0_1_) = (EIF_INTEGER_32) ti4_1;
	}
	if ((EIF_BOOLEAN)(arg6 != NULL)) {
		ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg6) + O9679[Dtype(arg6)-1201]);
		*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_1_0_2_) = (EIF_INTEGER_32) ti4_1;
	}
	RTLE;
}

/* {FORMAL_DEC_AS}.process */
void F1129_11742 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	
	
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R2487[Dtype(RTCW(arg1))-204])(arg1, Current);
}

/* {FORMAL_DEC_AS}.constrain_symbol */
EIF_REFERENCE F1129_11747 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	
	
	return (EIF_REFERENCE) F1118_11583(Current, arg1, *(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_1_0_0_));
}

/* {FORMAL_DEC_AS}.create_keyword */
EIF_REFERENCE F1129_11748 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	
	
	return (EIF_REFERENCE) F1118_11582(Current, arg1, *(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_1_0_1_));
}

/* {FORMAL_DEC_AS}.end_keyword */
EIF_REFERENCE F1129_11749 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	
	
	return (EIF_REFERENCE) F1118_11582(Current, arg1, *(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_1_0_2_));
}

/* {FORMAL_DEC_AS}.first_token */
EIF_REFERENCE F1129_11759 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLR(3,Result);
	RTLIU(4);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current);
	Result = F1188_12344(RTCW(tr1), arg1);
	RTLE;
	return Result;
}

/* {FORMAL_DEC_AS}.last_token */
EIF_REFERENCE F1129_11760 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,arg1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,Result);
	RTLIU(4);
	
	RTGC;
	if ((EIF_BOOLEAN) ((EIF_BOOLEAN)(arg1 != NULL) && (EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_1_0_2_) != ((EIF_INTEGER_32) 0L)))) {
		RTLE;
		return (EIF_REFERENCE) F1129_11749(Current, arg1);
	} else {
		if ((EIF_BOOLEAN)(*(EIF_REFERENCE *)(Current + _REFACS_1_) != NULL)) {
			tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
			Result = F1192_12396(RTCW(tr1), arg1);
		} else {
			tr1 = *(EIF_REFERENCE *)(Current);
			Result = F1188_12345(RTCW(tr1), arg1);
		}
	}
	RTLE;
	return Result;
}

void EIF_Minit466 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
